@@ -656,10 +656,11 @@ bus_spi_da1469x_dev_init_func(struct os_dev *odev, void *arg)
 
 #if MYNEWT_VAL(SPI_DA1469X_STAT)
     asprintf(&stats_name, "spi_da1469x_%d", cfg->spi_num);
-    stats_init_and_reg(STATS_HDR(dd->stats),
-                       STATS_SIZE_INIT_PARMS(dd->stats, STATS_SIZE_32),
-                       STATS_NAME_INIT_PARMS(spi_da1469x_stats_section),
-                       stats_name);
+    rc = stats_init_and_reg(STATS_HDR(dd->stats),
+                            STATS_SIZE_INIT_PARMS(dd->stats, STATS_SIZE_32),
+                            STATS_NAME_INIT_PARMS(spi_da1469x_stats_section),
+                            stats_name);
+    assert(rc == 0);
 #endif
 
     rc = bus_dev_init_func(odev, (void *)&bus_spi_da1469x_ops);
