@@ -25,6 +25,8 @@
 #include <hal/hal_spi.h>
 #include <mcu/nrf5340_hal.h>
 #include <nrf.h>
+#include <nrfx_config.h>
+#include <nrfx_common.h>
 
 #define SPIM_TXD_MAXCNT_MAX 0xffff
 
@@ -347,9 +349,9 @@ hal_spi_config_master(struct nrf5340_hal_spi *spi,
      */
     pin = spim->PSEL.SCK & SPIM_PSEL_SCK_PIN_Msk;
     if (spim->PSEL.SCK & SPIM_PSEL_SCK_PORT_Msk) {
-        port = NRF_P1_S;
+        port = NRF_P1;
     } else {
-        port = NRF_P0_S;
+        port = NRF_P0;
     }
 
     if (settings->data_mode <= HAL_SPI_MODE1) {
@@ -960,7 +962,11 @@ hal_spi_txrx_noblock(int spi_num, void *txbuf, void *rxbuf, int len)
     rc = EINVAL;
     NRF5340_HAL_SPI_RESOLVE(spi_num, spi);
 
-    if ((spi->txrx_cb_func == NULL) || (len == 0)) {
+    if ((spi->txrx_cb_func == NULL) || (len == 0) || !nrfx_is_in_ram(txbuf)) {
+        goto err;
+    }
+
+    if (rxbuf != NULL && !nrfx_is_in_ram(rxbuf)) {
         goto err;
     }
 
