@@ -710,7 +710,8 @@ insert_char(char *pos, char c)
     if (trailing_chars == 0) {
         *pos = c;
         if (!MYNEWT_VAL_CHOICE(CONSOLE_HISTORY, none) &&
-            MYNEWT_VAL(CONSOLE_HISTORY_AUTO_SEARCH) && cur > 1) {
+            MYNEWT_VAL(CONSOLE_HISTORY_AUTO_SEARCH) &&
+            echo != 0 && cur > 1) {
             history_line = 0;
             console_history_search(pos - cur + 1, HFT_MATCH_PREV);
             return;
@@ -1186,7 +1187,7 @@ console_handle_char(uint8_t byte)
                 console_filter_out('\n');
             }
             if (!MYNEWT_VAL_CHOICE(CONSOLE_HISTORY, none)) {
-                console_history_add(input->line);
+                console_history_add(input->line, NULL);
                 history_line = 0;
                 if (MYNEWT_VAL(CONSOLE_HISTORY_AUTO_SEARCH)) {
                     trailing_selection = 0;
@@ -1250,6 +1251,9 @@ console_is_init(void)
 #endif
 #if MYNEWT_VAL(CONSOLE_USB)
     return usb_cdc_console_is_init();
+#endif
+#if MYNEWT_VAL(CONSOLE_TCP)
+    return tcp_console_is_init();
 #endif
     return 0;
 }
